Attribute VB_Name = "Module1"
' *****************************************************************************
' File    : Image2PDF.bas
' Author  : Utility Warrior, (c) 2005-2008
' Project : Image to PDF (Image2PDF) Dynamic Link Library
' Purpose : This file provides Visual Basic 6 prototypes for all DLL functions
'
' Please refer to the accompanying documentation for full details.
'
' To use the Image to PDF DLL with Visual Basic you will need to use the alternative
' "Image2PDF StdCall.dll" which uses the Windows stdcall calling convention instead
' of the default DLL which uses the C calling convention.
'
' To do this rename the existing "Image2PDF.dll" as "Image2PDF-C.dll" and then rename
' "Image2PDF StdCall.dll" as "Image2PDF.dll".
'
' *****************************************************************************


' *************************************************************************
' This allows the support of multiple versions of a DLL (if and when
' available) so that functions that might only be available in a later
' version can then only be called if the returned version currently being
' used is one that supports those functions.
'
' Return value: integer value representing the DLL version
' a value of 100 is equivalent to version 1.00
' *************************************************************************
Declare Function I2PDF_GetDLLVersion Lib "Image2PDF.dll" () As Long


' *************************************************************************
' Required and Miscellaneous
' *************************************************************************
Declare Sub I2PDF_License Lib "Image2PDF.dll" (ByVal code As String)
' This is required to remove the "Evaluation Mode" message that is stamped
' over the top of every page in the output PDF document.
'
' To purchase a license code please visit the Utility Warrior web site which
' has the latest information and prices on the licenses that are available.
'
' Return value: none

Declare Function I2PDF_WildcardFilenameUse Lib "Image2PDF.dll" (ByVal flags As Long) As Long
' This can only be specified if the PDF filename is *.pdf AND only one wildcarded
' image name is used.
'
' Note: This must be set BEFORE I2PDF_AddImage is used
'
' flags can be:
' 0 - default of one pdf produced per image with no recursion
' 1 - Per Directory (forces creation of a single PDF file - with the name of that directory and saved in that directory - for the entire contents of a directory rather than one per image
' 2 - Directory Recursion (wildcarded image filename is looked for in all sub-directories below the directory which is referenced by the wildcarded image name)
' 3 - both Per Directory and Directory Recursion
'
' Return value:
' 0 - success
' 1 - images have already been added

Declare Function I2PDF_AddImage Lib "Image2PDF.dll" (ByVal image As String) As Long
' Specifies the name and location of an image to embed within the output PDF
' document. The image can be one of the following types: JPG, TIF, PNG, GIF, BMP, WMF, EMF, PCX or TGA.
'
' Up to 1000 images can be included.
'
' Images are embedded in the output PDF document in the order that they are
' referenced.
'
' Image filenames can contain the wildcard characters * and ? that allow multiple images
' to be referenced in one go. These characters can only be in the filename and not in any
' part of the filepath before the filename.
'
' Return value:
' 0 - success
' 1 - invalid parameter
' 2 - maximum number of images already added
' 3 - invalid image type
' 4 - image does not exist

Declare Function I2PDF_AddImageBookmark Lib "Image2PDF.dll" (ByVal image As String, ByVal bookmark As String) As Long
' Specifies the name and location of an image to embed within the output PDF
' document. The image can be one of the following types: JPG, TIF, PNG, GIF, BMP, WMF, EMF, PCX or TGA.
'
' Up to 1000 images can be included.
'
' Images are embedded in the output PDF document in the order that they are
' referenced.
'
' Return value:
' 0 - success
' 1 - invalid image parameter
' 2 - maximum number of images already added
' 3 - invalid image type
' 4 - invalid bookmark parameter
' 5 - image does not exist

Declare Function I2PDF_Log Lib "Image2PDF.dll" (ByVal logFilename As String, ByVal logLevel As Long) As Long
' Information and error messages are appended to the end of the file specified (with a timestamp).
'
' Set logLevel to one or more (by adding required log levels together) of:
' 1 to log image width, height, bit depth and DPI for each image that is converted.
' 2 font matching information.
' 4 filename wildcard matching information.
' 8 Bates number information.
'
' Return value:
' 0 - success
' 1 - invalid logFilename

Declare Function I2PDF_TreatImageNumericExtensionAs Lib "Image2PDF.dll" (ByVal imageExtension As String) As Long
Declare Function I2PDF_TreatImageNumericExtAs Lib "Image2PDF.dll" (ByVal imageExtension As String) As Long
' Some images may have a numeric sequenced number extension (eg image.001, image.002 etc) which would normally prevent
' the image from being identified as a valid one. To get around this problem use this
' function and pass it the image extension type that a numeric extension will be interpreted
' as (eg ".jpg", ".tif", ".png", ".gif", ".bmp", ".wmf", ".emf", ".pcx", ".tga")
'
' Return value:
' 0 - success
' 1 - extension not specified
' 2 - extension does not start with a .
' 3 - extension is not 4 characters long

Declare Function I2PDF_TreatImageTmpExtensionAs Lib "Image2PDF.dll" (ByVal imageExtension As String) As Long
Declare Function I2PDF_TreatImageTmpExtAs Lib "Image2PDF.dll" (ByVal imageExtension As String) As Long
' Some images may have a TMP extension which would normally prevent
' the image from being identified as a valid one. To get around this problem use this
' function and pass it the image extension type that a TMP extension will be interpreted
' as (eg ".jpg", ".tif", ".png", ".gif", ".bmp", ".wmf", ".emf", ".pcx", ".tga")
'
' Return value:
' 0 - success
' 1 - extension not specified
' 2 - extension does not start with a .
' 3 - extension is not 4 characters long

Declare Function I2PDF_TreatImageExtensionAs Lib "Image2PDF.dll" (ByVal sourceExtension As String, ByVal targetExtension As String) As Long
Declare Function I2PDF_TreatImageExtAs Lib "Image2PDF.dll" (ByVal sourceExtension As String, ByVal targetExtension As String) As Long
' Some images may have a non-standard image extension which would normally prevent
' the image from being identified as a valid one. To get around this problem use this
' function to map one of these extensions as a known one
' (eg ".jpg", ".tif", ".png", ".gif", ".bmp", ".wmf", ".emf", ".pcx", ".tga")
'
' Return value:
' 0 - success
' 1 - source extension not specified
' 2 - source extension does not start with a .
' 3 - target extension not specified
' 4 - target extension does not start with a .
' 5 - target extension is not 4 characters long
' 6 - max image extension mappings already defined

Declare Function I2PDF_MetaImageMaxMP Lib "Image2PDF.dll" (ByVal maxmp As Double) As Long
' Specifies the meta image (EMF or WMF) maximum rendering size.
'
' Return value:
' 0 - success
' 1 - invalid maxmp parameter


Declare Function I2PDF_MetaImageMaxMP_Int Lib "Image2PDF.dll" (ByVal maxmp As Long) As Long
' Specifies the meta image (EMF or WMF) maximum rendering size.
'
' Return value:
' 0 - success
' 1 - invalid maxmp parameter


Declare Sub I2PDF_MetaMargins Lib "Image2PDF.dll" ()
' Preserve the margins around the meta image (no matter how large they might be)
'
' Return value:
' None


Declare Sub I2PDF_MetaToNativePDF Lib "Image2PDF.dll" ()
' Forces meta image files to be converted into a native PDF representation
'
' Return value: none


Declare Sub I2PDF_CenterMetaImageOnPage Lib "Image2PDF.dll" ()
' Force a native rendered page to have the contents centered on the page based on the content of the meta image that is actually rendered into the PDF
'
' Return value: none 


Public Const FORCED_FONT_QUALITY_DRAFT = 1
Public Const FORCED_FONT_QUALITY_PROOF = 2
Public Const FORCED_FONT_QUALITY_NONANTIALIASED = 3
Public Const FORCED_FONT_QUALITY_ANIALIASED = 4
Public Const FORCED_FONT_QUALITY_CLEARTYPE = 5
Declare Function I2PDF_MetaBitmapForcedFontQuality Lib "Image2PDF.dll" (ByVal quality As Long) As Long
Declare Function I2PDF_MetaBitmapForcedFontQ Lib "Image2PDF.dll" (ByVal quality As Long) As Long
' This API can only be used if the I2PDF_MetaToNativePDF API has NOT been used as it controls the font quality when rendering the meta image file into a bitmap. 
'
' Return value:
' 0 - success
' 1 - invalid quality


Declare Sub I2PDF_MetaTextFitBoundingRect Lib "Image2PDF.dll" ()
' If text in a meta image file is larger than the defined bounding rectangle this command will progressively
' reduce the font size until it can fit the text within the defined bounding area.
'
'  Return value: none


Declare Sub I2PDF_UseEMFDeviceSize Lib "Image2PDF.dll" ()
' Determine the size of an EMF meta file by using the embedded reference device bounds.
'
' Return value: none


Declare Sub I2PDF_UseEMFFrameSize Lib "Image2PDF.dll" ()
' Determine the size of an EMF meta file by using the embedded frame size.
'
' Return value: none


Declare Function I2PDF_MetaImageScale Lib "Image2PDF.dll" (ByVal percentage As Double) As Long
' Specifies the meta image (EMF or WMF) scaling factor.
'
' Return value:
' 0 - success
' 1 - invalid percentage parameter


Declare Function I2PDF_MetaImageScale_Int Lib "Image2PDF.dll" (ByVal percentage As Long) As Long
' Specifies the meta image (EMF or WMF) scaling factor.
'
' Return value:
' 0 - success
' 1 - invalid percentage parameter


Declare Function I2PDF_MetaVerticalRenderScale Lib "Image2PDF.dll" (ByVal metaScale As Double) As Long
' Specifies the meta image (EMF or WMF) vertical scaling factor during rendering.
'
' Return value:
' 0 - success
' 1 - invalid scale parameter


Declare Function I2PDF_MetaVerticalRenderScale_Int Lib "Image2PDF.dll" (ByVal metaScale As Long) As Long
Declare Function I2PDF_MetaVertRenderScale_Int Lib "Image2PDF.dll" (ByVal metaScale As Long) As Long
' Specifies the meta image (EMF or WMF) vertical scaling factor during rendering.
'
' Return value:
' 0 - success
' 1 - invalid scale parameter


Public Const VERTICAL_ALIGNMENT_TOP = 1
Public Const VERTICAL_ALIGNMENT_MIDDLE = 2
Public Const VERTICAL_ALIGNMENT_BOTTOM = 3
Public Const HORIZONTAL_ALIGNMENT_LEFT = 1
Public Const HORIZONTAL_ALIGNMENT_CENTER = 2
Public Const HORIZONTAL_ALIGNMENT_RIGHT = 3
Declare Function I2PDF_ImageStamp Lib "Image2PDF.dll" (ByVal image As String, ByVal verticalPosition As Long, ByVal horizontalPosition As Long, ByVal margin As Double) As Long
Declare Function I2PDF_ImageStamp_Int Lib "Image2PDF.dll" (ByVal image As String, ByVal verticalPosition As Long, ByVal horizontalPosition As Long, ByVal margin As Long) As Long
' Specifies the name and location of an image that is "stamped" at the specified
' location on each page of the output PDF document. A margin between the image
' stamp and the edge of the page can be specified if required.
'
' Return value:
' 0 - success
' 1 - invalid image parameter
' 2 - invalid vertical position
' 3 - invalid horizontal position
' 4 - invalid margin


Declare Function I2PDF_MetaStampImageMaxMP Lib "Image2PDF.dll" (ByVal maxmp As Double) As Long
' Specifies the meta image (EMF or WMF) maximum rendering size for an image stamp.
'
' Return value:
' 0 - success
' 1 - invalid maxmp parameter
        

Declare Function I2PDF_MetaStampImageMaxMP_Int Lib "Image2PDF.dll" (ByVal maxmp As Long) As Long
' Specifies the meta image (EMF or WMF) maximum rendering size for an image stamp.
'
' Return value:
' 0 - success
' 1 - invalid maxmp parameter
        

Declare Function I2PDF_MetaStampImageScale Lib "Image2PDF.dll" (ByVal percentage As Double) As Long
' Specifies the meta image (EMF or WMF) scaling factor for an image stamp
'
' Return value:
' 0 - success
' 1 - invalid percentage parameter
        

Declare Function I2PDF_MetaStampImageScale_Int Lib "Image2PDF.dll" (ByVal percentage As Long) As Long
' Specifies the meta image (EMF or WMF) scaling factor for an image stamp
'
' Return value:
' 0 - success
' 1 - invalid percentage parameter


Declare Function I2PDF_MetaDefaultFont Lib "Image2PDF.dll" (ByVal fontname As String) As Long
' If a font cannot be matched then this allows the specification of one of the standard PDF fonts to be used:
'
' Courier
' Courier-Bold
' Courier-BoldOblique
' Courier-Oblique
' Helvetica
' Helvetica-Bold
' Helvetica-BoldOblique
' Helvetica-Oblique
' Times-Roman
' Times-Bold
' Times-Italic
' Times-BoldItalic
'
' Return value:
' 0 - success
' 1 - invalid font name


Declare Function I2PDF_MetaDefaultFontXScaling Lib "Image2PDF.dll" (ByVal scaleFactor As Double) As Long
' If a font cannot be matched (perhaps because it is not a True Type font with a CMAP record) then this 
' allows the arbitrary scaling of the width of the font in order to better match the actual physical 
' dimensions of the substituted font. Can only be used in conjunction with I2PDF_MetaDefaultFont
'
' Return value:
' 0 - success
' 1 - invalid scale factor parameter


Declare Sub I2PDF_UseArabicContextualForms Lib "Image2PDF.dll" ()
Declare Sub I2PDF_UseArabicContextForms Lib "Image2PDF.dll" ()
' By default, when Arabic Unicode text is used (codepage CP1256) the Arabic glyphs do not 
' take into account the context and relationship with other Arabic and non-Arabic text.
' This command will enable the analysis of the surrounding text in order to change the glyph to one of
' the contextual Arabic alternatives (known as initial, medial, final and isolated forms)
'
' Return value: none 


Declare Sub I2PDF_EmbedFonts Lib "Image2PDF.dll" ()
' If a document is converted which uses an unusual font that is not likely to be installed on a target 
' system then this	command will ensure that all of the font details are embedded within the PDF so that 
' the target system that a PDF may be viewed on does not require the font in order to display the text 
' within the PDF correctly.
'
' Return value: none 


Declare Function I2PDF_StampURL Lib "Image2PDF.dll" (ByVal url As String) As Long
' This is optional and specifies the URL that the image stamp will open in the default browser when it is clicked on.
'
' A maximum of 128 characters can be used.
'
' Return value:
' 0 - success
' 1 - invalid parameter


Declare Function I2PDF_MetaToNativeFontSubstitution Lib "Image2PDF.dll" (ByVal fontSubs As String) As Long
Declare Function I2PDF_MetaToNativeFontSubs Lib "Image2PDF.dll" (ByVal fontSubs As String) As Long
' If a font cannot be matched (perhaps because it is not a True Type font with a CMAP record) 
' then this allows an alternative font and specific character substitutions to be made. 
'
' Return value:
' 0 - success
' 1 - invalid substitution description
' 2 - maximum number of substitution strings already defined


Public Const SLIDESHOW_WIPE_RIGHT = 1
Public Const SLIDESHOW_WIPE_UP = 2
Public Const SLIDESHOW_WIPE_LEFT = 3
Public Const SLIDESHOW_WIPE_DOWN = 4
Public Const SLIDESHOW_BARN_DOORS_HORIZONTAL_OUT = 5
Public Const SLIDESHOW_BARN_DOORS_HORIZONTAL_IN = 6
Public Const SLIDESHOW_BARN_DOORS_VERTICAL_OUT = 7
Public Const SLIDESHOW_BARN_DOORS_VERTICAL_IN = 8
Public Const SLIDESHOW_BOX_OUT = 9
Public Const SLIDESHOW_BOX_IN = 10
Public Const SLIDESHOW_BLINDS_HORIZONTAL = 11
Public Const SLIDESHOW_BLINDS_VERTICAL = 12
Public Const SLIDESHOW_DISSOLVE = 13
Public Const SLIDESHOW_GLITTER_RIGHT = 14
Public Const SLIDESHOW_GLITTER_DOWN = 15
Public Const SLIDESHOW_GLITTER_TOP_LEFT_TO_BOTTOM_RIGHT = 16
Public Const SLIDESHOW_REPLACE = 17
Declare Function I2PDF_SlideShow Lib "Image2PDF.dll" (ByVal transition As Long, ByVal transitionDuration As Double, ByVal pageDisplayDuration As Double) As Long
Declare Function I2PDF_SlideShow_Int Lib "Image2PDF.dll" (ByVal transition As Long, ByVal transitionDuration As Long, ByVal pageDisplayDuration As Long) As Long
' Forces the PDF document to be displayed full screen with the chosen screen transition between each page.
'
' Return value:
' 0 - success
' 1 - invalid transition
' 2 - invalid transition duration
' 3 - invalid page display duration


Declare Sub I2PDF_DeleteImagesOnConvert Lib "Image2PDF.dll" ()
' When the PDF document has been successfully produced all of the images converted to PDF are deleted.
'
' Return value: none


Declare Function I2PDF_SetBorder Lib "Image2PDF.dll" (ByVal left As Double, ByVal top As Double, ByVal right As Double, ByVal bottom As Double) As Long
Declare Function I2PDF_SetBorder_Int Lib "Image2PDF.dll" (ByVal left As Long, ByVal top As Long, ByVal right As Long, ByVal bottom As Long) As Long
' Allows a border to be inserted between the image and the edge of the PDF page.
' The border color can be specified by using one of the three I2PDF_SetBorderColor_Real/Int/Web APIs below.
' This can be useful if you want to add an image stamp to each page but do not want it to obscure the image.
'
' Return value:
'  0 - success
'  1 - invalid left value
'  2 - invalid top value
'  3 - invalid right value
'  4 - invalid bottom value


Declare Function I2PDF_SetBorderColor_Real Lib "Image2PDF.dll" (ByVal red As Double, ByVal green As Double, ByVal blue As Double) As Long
' Set the border color to use when I2PDF_SetBorder has been used.
' Color is made up of a combination of three components: red, green and blue.
' The value of each color component controls how much of that color is displayed, with a value of
' 0.0 representing none up to a value of 100.0 representing the maximum value.
'
' Return value:
' 0 - success
' 1 - invalid red value
' 2 - invalid green value
' 3 - invalid blue value


Declare Function I2PDF_SetBorderColor_Int Lib "Image2PDF.dll" (ByVal red As Long, ByVal green As Long, ByVal blue As Long) As Long
' Set the border color to use when I2PDF_SetBorder has been used.
' Color is made up of a combination of three components: red, green and blue.
' The value of each color component controls how much of that color is displayed, with a value of
' 0 representing none up to a value of 255 representing the maximum value.
'
' Return value:
' 0 - success
' 1 - invalid red value
' 2 - invalid green value
' 3 - invalid blue value


Declare Function I2PDF_SetBorderColor_Web Lib "Image2PDF.dll" (ByVal color As String) As Long
' Set the border color to use when I2PDF_SetBorder has been used.
' Color is made up of a combination of three components: red, green and blue.
' Web colours are specified by using three pairs of hexadecimal digits.
' The value of each color component controls how much of that color is displayed, with a value of
' 00 representing none up to a value of FF representing the maximum value.
'
' Return value:
' 0 - success
' 1 - invalid color value


Declare Sub I2PDF_SilentRunning Lib "Image2PDF.dll" ()
' Prevents information from being printed to the console window
'
' Return value: none


Declare Sub I2PDF_PreventPDFOverwrite Lib "Image2PDF.dll" ()
' Prevents an existing PDF from being overwritten
'
' Return value: none


Declare Function I2PDF_SaveFailureBackupPDF Lib "Image2PDF.dll" (ByVal filename As String) As Long
' Will save the PDF to a backup filename if the required file cannot be written (perhaps because another application has the target PDF currently open). 
'
' Return value:
' 0 - success
' 1 - invalid filename


Declare Sub I2PDF_IncludeTIFFOCRText Lib "Image2PDF.dll" ()
' Includes any OCR'd text stored within the TIFF file (eg produced by Microsoft Document Imaging) as invisible "searchable" text within the PDF. 
'
' Return value: none


Declare Sub I2PDF_SaveTIFFOCRText Lib "Image2PDF.dll" (ByVal text As String)
' Outputs any OCR'd text stored within the TIFF file (eg produced by Microsoft Document Imaging) into a text file with the same name and in the same location as the produced PDF.
'
' Return value: none


Declare Function I2PDF_LoadImageFailureCopyTo Lib "Image2PDF.dll" (ByVal copyToDir As String) As Long
Declare Function I2PDF_LoadImageFailCopyTo Lib "Image2PDF.dll" (ByVal copyToDir As String) As Long
' Allows images that fail to be copied to the specified directory (for a manual or monitoring process to deal with).
'
' Return value:
' 0 - success
' 1 - invalid copyToDir


Declare Sub I2PDF_LoadImageFailureSkip Lib "Image2PDF.dll" ()
Declare Sub I2PDF_LoadImageFailSkip Lib "Image2PDF.dll" ()
' Allows images that fail to be skipped over so that all valid images are still converted and a PDF produced. 
'
' Return value: none


Declare Function I2PDF_LoadImageFailurePage_Real Lib "Image2PDF.dll" (ByVal width As Long, ByVal height As Long, ByVal dblBackgroundRed As Double, ByVal dblBackgroundGreen As Double, ByVal dblBackgroundBlue As Double, ByVal message As String) As Long
Declare Function I2PDF_LoadImageFailPg_Real Lib "Image2PDF.dll" (ByVal width As Long, ByVal height As Long, ByVal dblBackgroundRed As Double, ByVal dblBackgroundGreen As Double, ByVal dblBackgroundBlue As Double, ByVal message As String) As Long
' Allows images that fail to still have a page in the PDF but with the required message.
'
' Return value:
' 0 - success
' 1 - invalid width
' 2 - invalid height
' 3 - invalid backgroundRed
' 4 - invalid backgroundGreen
' 5 - invalid backgroundBlue
' 6 - invalid message 


Declare Function I2PDF_LoadImageFailurePage_Int Lib "Image2PDF.dll" (ByVal width As Long, ByVal height As Long, ByVal backgroundRed As Long, ByVal backgroundGreen As Long, ByVal backgroundBlue As Long, ByVal message As String) As Long
Declare Function I2PDF_LoadImageFailPg_Int Lib "Image2PDF.dll" (ByVal width As Long, ByVal height As Long, ByVal backgroundRed As Long, ByVal backgroundGreen As Long, ByVal backgroundBlue As Long, ByVal message As String) As Long
' Allows images that fail to still have a page in the PDF but with the required message.
'
' Return value:
' 0 - success
' 1 - invalid width
' 2 - invalid height
' 3 - invalid backgroundRed
' 4 - invalid backgroundGreen
' 5 - invalid backgroundBlue
' 6 - invalid message 


Declare Function I2PDF_LoadImageFailurePage_Web Lib "Image2PDF.dll" (ByVal width As Long, ByVal height As Long, ByVal backgroundColor As String, ByVal ByValmessage As String) As Long
Declare Function I2PDF_LoadImageFailPg_Web Lib "Image2PDF.dll" (ByVal width As Long, ByVal height As Long, ByVal backgroundColor As String, ByVal ByValmessage As String) As Long
' Allows images that fail to still have a page in the PDF but with the required message.
'
' Return value:
' 0 - success
' 1 - invalid width
' 2 - invalid height
' 3 - invalid backgroundColor
' 4 - invalid message 


Declare Function I2PDF_LoadImageFailurePageFont_Real Lib "Image2PDF.dll" (ByVal iSize As Long, ByVal font As String, ByVal dblFillRed As Double, ByVal dblFillGreen As Double, ByVal dblFillBlue As Double, ByVal iStyle As Long, ByVal dblOtherRed As Double, ByVal dblOtherGreen As Double, ByVal dblOtherBlue As Double) As Long
Declare Function I2PDF_LoadImageFailPgFnt_Real Lib "Image2PDF.dll" (ByVal iSize As Long, ByVal font As String, ByVal dblFillRed As Double, ByVal dblFillGreen As Double, ByVal dblFillBlue As Double, ByVal iStyle As Long, ByVal dblOtherRed As Double, ByVal dblOtherGreen As Double, ByVal dblOtherBlue As Double) As Long
' Controls the display of the failure message text specified in I2PDF_LoadImageFailurePage_Real/Int/Web.
'
' Return value:
' 0 - success
' 1 - invalid size
' 2 - invalid font
' 3 - invalid fillRed
' 4 - invalid fillGreen
' 5 - invalid fillBlue
' 6 - invalid style
' 7 - invalid otherRed
' 8 - invalid otherGreen
' 9 - invalid otherBlue 


Declare Function I2PDF_LoadImageFailurePageFont_Int Lib "Image2PDF.dll" (ByVal iSize As Long, ByVal font As String, ByVal fillRed As Long, ByVal fillGreen As Long, ByVal fillBlue As Long, ByVal iStyle As Long, ByVal otherRed As Long, ByVal otherGreen As Long, ByVal otherBlue As Long) As Long
Declare Function I2PDF_LoadImageFailPgFnt_Int Lib "Image2PDF.dll" (ByVal iSize As Long, ByVal font As String, ByVal fillRed As Long, ByVal fillGreen As Long, ByVal fillBlue As Long, ByVal iStyle As Long, ByVal otherRed As Long, ByVal otherGreen As Long, ByVal otherBlue As Long) As Long
' Controls the display of the failure message text specified in I2PDF_LoadImageFailurePage_Real/Int/Web.
'
' Return value:
' 0 - success
' 1 - invalid size
' 2 - invalid font
' 3 - invalid fillRed
' 4 - invalid fillGreen
' 5 - invalid fillBlue
' 6 - invalid style
' 7 - invalid otherRed
' 8 - invalid otherGreen
' 9 - invalid otherBlue 


Declare Function I2PDF_LoadImageFailurePageFont_Web Lib "Image2PDF.dll" (ByVal iSize As Long, ByVal font As String, ByVal fillColor As String, ByVal iStyle As Long, ByVal otherColor As String) As Long
Declare Function I2PDF_LoadImageFailPgFnt_Web Lib "Image2PDF.dll" (ByVal iSize As Long, ByVal font As String, ByVal fillColor As String, ByVal iStyle As Long, ByVal otherColor As String) As Long
' Controls the display of the failure message text specified in I2PDF_LoadImageFailurePage_Real/Int/Web.
'
' Return value:
' 0 - success
' 1 - invalid size
' 2 - invalid font
' 3 - invalid fillColor
' 4 - invalid style
' 5 - invalid otherColor 


' *****************************************************************************
' Bates (Page/Document) Numbering
' *****************************************************************************
Declare Function I2PDF_BatesFormat Lib "Image2PDF.dll" (ByVal format As String) As Long
' Specifies the text to display on each page of the output PDF. This is typically
' a combination of static text plus one or more special Bates markup formatting labels.
' See the manual for full details.
'
' Return value:
' 0 - success
' 1 - invalid format


Declare Function I2PDF_BatesLocation Lib "Image2PDF.dll" (ByVal verticalPosition As Long, ByVal horizontalPosition As Long, ByVal orientation As Long, ByVal margin As Double) As Long
' This is optional and specifies the location that the Bates "number" is displayed on each page of the output PDF document. 
'
' Return value:
' 0 - success
' 1 - invalid verticalPosition
' 2 - invalid horizontalPosition
' 3 - invalid textOrientation
' 4 - invalid margin 


Declare Function I2PDF_BatesLocation_Int Lib "Image2PDF.dll" (ByVal verticalPosition As Long, ByVal horizontalPosition As Long, ByVal orientation As Long, ByVal margin As Long) As Long
' This is optional and specifies the location that the Bates "number" is displayed on each page of the output PDF document. 
'
' Return value:
' 0 - success
' 1 - invalid verticalPosition
' 2 - invalid horizontalPosition
' 3 - invalid textOrientation
' 4 - invalid margin 


Public Const TEXT_STYLE_NORMAL = 1
Public Const TEXT_STYLE_STROKE = 2
Declare Function I2PDF_BatesFont_Real Lib "Image2PDF.dll" (ByVal iSize As Long, ByVal fontID As String, ByVal fillRed As Double, ByVal fillGreen As Double, ByVal fillBlue As Double, ByVal iStyle As Long, ByVal otherRed As Double, ByVal otherGreen As Double, ByVal otherBlue As Double) As Long
' This is optional and controls the display of the Bates "number". 
'
' Return value:
' 0 - success
' 1 - invalid size
' 2 - invalid fontID
' 3 - invalid fillRed
' 4 - invalid fillGreen
' 5 - invalid fillBlue
' 6 - invalid style
' 7 - invalid otherRed
' 8 - invalid otherGreen
' 9 - invalid otherBlue 


Declare Function I2PDF_BatesFont_Int Lib "Image2PDF.dll" (ByVal iSize As Long, ByVal fontID As String, ByVal fillRed As Long, ByVal fillGreen As Long, ByVal fillBlue As Long, ByVal iStyle As Long, ByVal otherRed As Long, ByVal otherGreen As Long, ByVal otherBlue As Long) As Long
' This is optional and controls the display of the Bates "number". 
'
' Return value:
' 0 - success
' 1 - invalid size
' 2 - invalid fontID
' 3 - invalid fillRed
' 4 - invalid fillGreen
' 5 - invalid fillBlue
' 6 - invalid style
' 7 - invalid otherRed
' 8 - invalid otherGreen
' 9 - invalid otherBlue 


Declare Function I2PDF_BatesFont_Web Lib "Image2PDF.dll" (ByVal iSize As Long, ByVal fontID As String, ByVal fillColor As String,ByVal iStyle As Long, ByVal otherColor As String) As Long
' This is optional and controls the display of the Bates "number". 
'
' Return value:
' 0 - success
' 1 - invalid size
' 2 - invalid fontID
' 3 - invalid fillColor
' 4 - invalid style
' 5 - invalid otherColor


Declare Function I2PDF_BatesFile Lib "Image2PDF.dll" (ByVal filename As String) As Long
' This is optional but is useful if you want to have sequential numbering continue automatically between documents. 
'
' Return value:
' 0 - success
' 1 - invalid filename


Declare Function I2PDF_BatesNumber Lib "Image2PDF.dll" (ByVal initialValue As Long) As Long
' This is optional and defines the initial Bates number used. 
'
' Return value:
' 0 - success


Declare Function I2PDF_BatesIncrement Lib "Image2PDF.dll" (ByVal value As Long) As Long
' This is optional and defines the amount by which the Bates number is incremented with use. 
'
' Return value:
' 0 - success
' 1 - invalid value


Public Const BATES_BACKGROUND_FILLED_RECT = 1
Public Const BATES_BACKGROUND_OUTLINE_RECT = 2
Declare Function I2PDF_BatesBackground_Real Lib "Image2PDF.dll" (ByVal shape As Long, ByVal backgroundRed As Double, ByVal backgroundGreen As Double, ByVal backgroundBlue As Double, ByVal borderRed As Double, ByVal borderGreen As Double, ByVal borderBlue As Double) As Long
' This is optional and if not specified no background is displayed behind the Bates "number". 
'
' Return value:
' 0 - success
' 1 - invalid shape
' 2 - invalid backgroundRed
' 3 - invalid backgroundGreen
' 4 - invalid backgroundBlue
' 5 - invalid borderRed
' 6 - invalid borderGreen
' 7 - invalid borderBlue 


Declare Function I2PDF_BatesBackground_Int Lib "Image2PDF.dll" (ByVal shape As Long, ByVal backgroundRed As Long, ByVal backgroundGreen As Long, ByVal backgroundBlue As Long, ByVal borderRed As Long, ByVal borderGreen As Long, ByVal borderBlue As Long) As Long
' This is optional and if not specified no background is displayed behind the Bates "number". 
'
' Return value:
' 0 - success
' 1 - invalid shape
' 2 - invalid backgroundRed
' 3 - invalid backgroundGreen
' 4 - invalid backgroundBlue
' 5 - invalid borderRed
' 6 - invalid borderGreen
' 7 - invalid borderBlue 


Declare Function I2PDF_BatesBackground_Web Lib "Image2PDF.dll" (ByVal shape As Long, ByVal backgroundColor As String, ByVal borderColor As String) As Long
' This is optional and if not specified no background is displayed behind the Bates "number". 
'
' Return value:
' 0 - success
' 1 - invalid shape
' 2 - invalid backgroundColor
' 3 - invalid borderColor


' *****************************************************************************
' Image Transformations
' *****************************************************************************


Declare Function I2PDF_Rotate Lib "Image2PDF.dll" (ByVal angle As Long) As Long
' Rotate image clockwise by a fixed amount (90, 180 or 270 degrees)
'
' Return value:
' 0 - success
' 1 - invalid angle


Public Const AUTOROTATE_PORTRAIT = 1
Public Const AUTOROTATE_LANDSCAPE = 2
Declare Function I2PDF_AutoRotate Lib "Image2PDF.dll" (ByVal orientation As Long, ByVal angle As Long) As Long
' Rotate image clockwise (if required) by a fixed amount (90 or 270 degrees)
' so that it is in portrait or landscape orientation
'
' Return value:
' 0 - success
' 1 - invalid orientation
' 2 - invalid angle


Public Const FLIP_HORIZONTAL = 1
Public Const FLIP_VERTICAL = 2
Declare Function I2PDF_Flip Lib "Image2PDF.dll" (ByVal orientation As Long) As Long
' Flip image horizontally (mirroring) or vertically
'
' Return value:
' 0 - success
' 1 - invalid orientation


Declare Sub I2PDF_Grayscale Lib "Image2PDF.dll" ()
' Ensure that an image is in grayscale - if it is in color it will be converted
'
' Return value:
' None


Declare Sub I2PDF_Negative Lib "Image2PDF.dll" ()
' Invert (negative) image
'
' Return value:
' None


Declare Function I2PDF_JpegCompress Lib "Image2PDF.dll" (ByVal quality As Long) As Long
' Force re-compression of all JPEG images, quality can be between 1 (low)
' to 35 (high). A value of 0 will turn re-compression off.
'
' Return value:
' 0 - success
' 1 - invalid angle


' *************************************************************************
' PDF Settings
' *************************************************************************
Public Const OUTLINE_FORMAT_FILENAME = 1
Public Const OUTLINE_FORMAT_NAME = 2
Public Const STYLE_NONE = 0
Public Const STYLE_LOWERCASE = 1
Public Const STYLE_UPPERCASE = 2
Public Const STYLE_CAPITALISE = 3

Declare Function I2PDF_SetOutline Lib "Image2PDF.dll" (ByVal format As Long, ByVal style As Long) As Long
' This turns on the generation of a bookmark for each image that is in the
' output PDF document.
'
' format can be either "filename" (this is the name of the image file including
' the image extension but not including the full filepath) or "name" (same as
' filename but without the image extension).
'
' style can be: "lowercase", "uppercase", "capitalise" or "none".
'
' Return value:
' 0 - success
' 1 - invalid format parameter
' 2 - invalid style parameter

Declare Function I2PDF_SetOutlineTitle Lib "Image2PDF.dll" (ByVal title As String) As Long
' If an outline is created this will set the title to be used instead of the default one.
'
' Return value:
' 0 - success
' 1 - title not specified
' 2 - title too long

Public Const PDF_PERMISSION_READ_ONLY = 0
Public Const PDF_PERMISSION_EDIT = 1
Public Const PDF_PERMISSION_EDIT_EXTRA = 2
Public Const PDF_PERMISSION_COPY = 4
Public Const PDF_PERMISSION_PRINT = 8
Declare Function I2PDF_SetPermissions Lib "Image2PDF.dll" (ByVal permissions As Long)
' Allows the setting of any combination of permissions in one go
'
' Return value:
' 0 - success
' 1 - invalid permissions

Declare Sub I2PDF_SetPermissionEdit Lib "Image2PDF.dll" ()
' Allows editing/changing of the PDF document but NOT adding or changing of text
' notes and AcroForm fields.
'
' Return value: none


Declare Sub I2PDF_SetPermissionEditExtra Lib "Image2PDF.dll" ()
' Allows the adding and changing of text notes and AcroForm fields within a PDF document.
'
' Return value: none


Declare Sub I2PDF_SetPermissionCopy Lib "Image2PDF.dll" ()
' Allows the copying of text and graphics from the PDF document.
'
' Return value: none


Declare Sub I2PDF_SetPermissionPrint Lib "Image2PDF.dll" ()
' Allows printing of the PDF document.
'
' Return value: none


Declare Function I2PDF_SetOwnerPassword Lib "Image2PDF.dll" (ByVal password As String) As Long
' The owner of a PDF document would enter this password in order to view it
' and make changes and perform actions that may be restricted to a normal user.
'
' A maximum of 32 characters can be used.
'
' Return value:
' 0 - success
' 1 - invalid parameter


Declare Function I2PDF_SetUserPassword Lib "Image2PDF.dll" (ByVal password As String) As Long
' In order that only the intended user can view the PDF document, they must type
' in this password, otherwise the user is not allowed to read the PDF document.
'
' A maximum of 32 characters can be used.
'
' Return value:
' 0 - success
' 1 - invalid parameter


Declare Function I2PDF_EncryptionLevel Lib "Image2PDF.dll" (ByVal level As Integer, ByVal force As Integer) As Long
' Specifies the level of encryption that is to be used on the PDF document. 
' If not specified the default level of 40 bits is used. 
'
' level must be either 40 (low) or 128 (high)
' force must be 1 to force the encryption or 0
'
' Return value:
' 0 - success
' 1 - invalid parameter

Declare Function I2PDF_MinImageSize Lib "Image2PDF.dll" (ByVal width As Integer, ByVal height As Integer) As Long
' Specifies the minimum image width and height required for an image to be converted.
'
' width and height must be > 0
'
' Return value:
' 0 - success
' 1 - invalid width
' 2 - invalid height


Declare Function I2PDF_SetDPI Lib "Image2PDF.dll" (ByVal dpi As Long) As Long
' PDF documents use a default resolution setting of 72 DPI. Images created for
' screen display under Windows will probably have a resolution of 96 DPI. If you
' have created images for printing then you will probably need to use 300 or 600 DPI.
'
' If you do not adjust the default resolution setting then when displayed within a
' PDF document on screen a 96 DPI image will appear 25% larger than expected. This
' gets much worse for a 300 DPI image which will appear 416% larger than expected.
'
' dpi must be between 9 and 2880 inclusive, or 0 to force the use of the actual
' image dpi that is recorded in the image file
'
' Return value:
' 0 - success
' 1 - invalid parameter - dpi specified is less than 9
' 2 - invalid parameter - dpi specified is greater than 2880


' *************************************************************************
' PDF Meta Information
' *************************************************************************
Declare Function I2PDF_SetProducer Lib "Image2PDF.dll" (ByVal producer As String) As Long
' The name of the application that converted the document from its native format to PDF.
'
' A maximum of 256 characters can be used.
'
' Return value:
' 0 - success
' 1 - invalid parameter


Declare Function I2PDF_SetCreator Lib "Image2PDF.dll" (ByVal creator As String) As Long
' If the document was converted into a PDF document from another form, this is
' usually the name of the application that created the original document.
'
' A maximum of 256 characters can be used.
'
' Return value:
' 0 - success
' 1 - invalid parameter


Declare Function I2PDF_SetAuthor Lib "Image2PDF.dll" (ByVal author As String) As Long
' The name of the person who created the PDF document.
'
' A maximum of 256 characters can be used.
'
' Return value:
' 0 - success
' 1 - invalid parameter


Declare Function I2PDF_SetTitle Lib "Image2PDF.dll" (ByVal title As String) As Long
' The PDF document's title.
'
' A maximum of 256 characters can be used.
'
' Return value:
' 0 - success
' 1 - invalid parameter


Declare Function I2PDF_SetSubject Lib "Image2PDF.dll" (ByVal subject As String) As Long
' The PDF document's subject.
'
' A maximum of 256 characters can be used.
'
' Return value:
' 0 - success
' 1 - invalid parameter


Declare Function I2PDF_SetKeywords Lib "Image2PDF.dll" (ByVal keywords As String) As Long
' A list of keywords associated with the PDF document.
'
' A maximum of 256 characters can be used.
'
' Return value:
' 0 - success
' 1 - invalid parameter


Declare Sub I2PDF_SetCreationDate Lib "Image2PDF.dll" ()
' The date that the PDF document was created.
'
' This is set using the current local time of the PC.
'
' Return value: none


' *************************************************************************
' PDF Viewer Preferences
' *************************************************************************
Declare Sub I2PDF_SetViewerPreferenceCenterWindow Lib "Image2PDF.dll" ()
Declare Sub I2PDF_SetViewPrefCenterWindow Lib "Image2PDF.dll" ()
' The window displaying the PDF document should be displayed in the center of
' the computer's screen.
'
' Return value: none


Declare Sub I2PDF_SetViewerPreferenceHideToolbar Lib "Image2PDF.dll" ()
Declare Sub I2PDF_SetViewPrefHideToolbar Lib "Image2PDF.dll" ()
' The PDF viewer's toolbar should be hidden when the PDF document is active.
'
' Return value: none


Declare Sub I2PDF_SetViewerPreferenceHideMenubar Lib "Image2PDF.dll" ()
Declare Sub I2PDF_SetViewPrefHideMenubar Lib "Image2PDF.dll" ()
' The PDF viewer's menubar should be hidden when the PDF document is active.
'
' Return value: none


Declare Sub I2PDF_SetViewerPreferenceHideWindowUI Lib "Image2PDF.dll" ()
Declare Sub I2PDF_SetViewPrefHideWindowUI Lib "Image2PDF.dll" ()
' The user interface elements within the PDF document's window should be hidden.
'
' Return value: none


Declare Sub I2PDF_SetViewerPreferenceFitWindow Lib "Image2PDF.dll" ()
Declare Sub I2PDF_SetViewPrefFitWindow Lib "Image2PDF.dll" ()
' The PDF viewer should resize the window displaying the PDF document to fit the
' size of the first displayed page of the PDF document.
'
' Return value: none


Declare Sub I2PDF_SetPageModeOutlines Lib "Image2PDF.dll" ()
' The PDF viewer should show the outline (ie bookmark) navigation item when the
' PDF document is open.
'
' Return value: none


Declare Sub I2PDF_SetPageModeNone Lib "Image2PDF.dll" ()
' The PDF viewer should not show the outline (ie bookmark) or thumbnail navigation
' items when the PDF document is open.
'
' This is the default if no other page mode is specified.
'
' Return value: none


Declare Sub I2PDF_SetPageModeUseThumbs Lib "Image2PDF.dll" ()
' The PDF viewer should show the thumbnail navigation item when the PDF document
' is open.
'
' Return value: none


Declare Sub I2PDF_SetPageModeFullScreen Lib "Image2PDF.dll" ()
' The PDF viewer should open the PDF document in full-screen mode without showing
' the menu bar, window controls or any other window.
'
' Return value: none


Declare Sub I2PDF_SetPageLayoutSinglePage Lib "Image2PDF.dll" ()
' Display the pages one page at a time.
'
' Return value: none


Declare Sub I2PDF_SetPageLayoutOneColumn Lib "Image2PDF.dll" ()
Declare Sub I2PDF_SetPageLayout1Col Lib "Image2PDF.dll" ()
' Display the pages in one column.
'
' Return value: none


Declare Sub I2PDF_SetPageLayoutTwoColumnLeft Lib "Image2PDF.dll" ()
Declare Sub I2PDF_SetPageLayout2ColLeft Lib "Image2PDF.dll" ()
' Display the pages in two columns, with odd-numbered pages on the left.
'
' Return value: none


Declare Sub I2PDF_SetPageLayoutTwoColumnRight Lib "Image2PDF.dll" ()
Declare Sub I2PDF_SetPageLayout2ColRight Lib "Image2PDF.dll" ()
' Display the pages in two columns, with odd-numbered pages on the right.
'
' Return value: none


' *************************************************************************
' Specifies the name and location of the produced PDF document,
' *************************************************************************
Public Const OPTION_NONE = 0
Public Const OPTION_OPEN_PDF = 1
Public Const OPTION_RESET = 2
Declare Function I2PDF_MakePDF Lib "Image2PDF.dll" (ByVal output As String, ByVal options As Long, ByVal errorText As Long, ByVal maxErrorTextSize As Long) As Long
' Generate the output PDF according to the settings already selected through
' the Application Programming Interface functions above.
'
' NB errorText must be passed as a byte array and the result converted back to a string, eg:
'    Dim result As Long
'    Dim errorText As String
'    Dim errorDLL(300) As Byte
'    result = I2PDF_MakePDF("Test.pdf", OPTION_NONE, VarPtr(errorDLL(0)), UBound(errorDLL))
'    If (result > 0) Then
'        errorText = StrConv(errorDLL, vbUnicode)
'        If (result = 3) Then
'            MessageBox 0, "I2PDF_MakePDF returned error " + errorText, "Error", 0
'        Else
'            MessageBox 0, "I2PDF_MakePDF returned error code " + CStr(result), "Error", 0
'        End If
'    End If
'
' To have the output PDF open in the default PDF viewer set the OPTION_OPEN_PDF
' bit flag in the options parameter.
'
' To have all settings applied reset after PDF has been generated set the OPTION_RESET
' bit flag in the options parameter.
'
'
' Return value:
' 0 - success
' 1 - invalid parameter
' 2 - output pdf could not be opened
' 3 - internal PDF generation error - error description returned in errorText
' 4 - PDF file already exists and could not be overwritten - it is possibly being held open by a PDF viewer application

Declare Sub I2PDF_Reset Lib "Image2PDF.dll" ()
' Reset all settings including the list of images added.
'
'  Return value: none
