// *****************************************************************************
// File    : Image2PDF.cpp
// Author  : Utility Warrior, (c) 2005-2008
// Project : Image to PDF (Image2PDF) Dynamic Link Library
// Purpose : This file provides C++ prototypes for all DLL functions
//
// Please refer to the accompanying documentation for full details.
// *****************************************************************************

#using <mscorlib.dll>

using namespace System;
using namespace System::Runtime::InteropServices;

public __gc class Win32 
{
public:
	// *************************************************************************
	// This allows the support of multiple versions of a DLL (if and when
	// available) so that functions that might only be available in a later
	// version can then only be called if the returned version currently being 
	// used is one that supports those functions.
	//   
	// Return value: integer value representing the DLL version
	// a value of 100 is equivalent to version 1.00
	// *************************************************************************
	[DllImport("Image2PDF.dll")]
	static int I2PDF_GetDLLVersion();


	// *************************************************************************
	// Required and Miscellaneous
	// *************************************************************************
	[DllImport("Image2PDF.dll")]
	static void I2PDF_License(char *code);
	// This is required to remove the "Evaluation Mode" message that is stamped 
	// over the top of every page in the output PDF document.   
	//
	// To purchase a license code please visit the Utility Warrior web site which 
	// has the latest information and prices on the licenses that are available. 
	//
	// Return value: none 


	#define WILDCARD_FILENAME_PER_DIRECTORY			1
	#define WILDCARD_FILENAME_DIRECTORY_RECURSION	2
	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_WildcardFilenameUse(int flags);
	// This can only be specified if the PDF filename is *.pdf AND only one wildcarded 
	// image name is used.
	//
	// Note: This must be set BEFORE I2PDF_AddImage is used
	//
	// flags can be:
	// 0 - default of one pdf produced per image with no recursion
	// 1 - Per Directory (forces creation of a single PDF file - with the name of that directory and saved in that directory - for the entire contents of a directory rather than one per image
	// 2 - Directory Recursion (wildcarded image filename is looked for in all sub-directories below the directory which is referenced by the wildcarded image name)
	// 3 - both Per Directory and Directory Recursion
	//
	// Return value:
	// 0 - success
	// 1 - images have already been added


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_AddImage(char *image);
	// Specifies the name and location of an image to embed within the output PDF 
	// document. The image can be one of the following types: JPG, TIF, PNG, GIF, BMP, WMF, EMF, PCX or TGA.
	//
	// Up to 1000 images can be included.
	//
	// Images are embedded in the output PDF document in the order that they are 
	// referenced.
	//
	// Image filenames can contain the wildcard characters * and ? that allow multiple images 
	// to be referenced in one go. These characters can only be in the filename and not in any 
	// part of the filepath before the filename.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter
	// 2 - maximum number of images already added
	// 3 - invalid image type
	// 4 - image does not exist


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_AddImageBookmark(char *image, char *bookmark);
	// Specifies the name and location of an image to embed within the output PDF 
	// document. The image can be one of the following types: JPG, TIF, PNG, GIF, BMP, WMF, EMF, PCX or TGA.
	//
	// Up to 1000 images can be included.
	//
	// Images are embedded in the output PDF document in the order that they are 
	// referenced.
	//
	// Return value:
	// 0 - success
	// 1 - invalid image parameter
	// 2 - maximum number of images already added
	// 3 - invalid image type
	// 4 - invalid bookmark parameter
	// 5 - image does not exist


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_Log(char *logFilename, int logLevel);
	// Information and error messages are appended to the end of the file specified (with a timestamp).
	//
	// Set logLevel to one or more (by adding required log levels together) of:
	// 1 to log image width, height, bit depth and DPI for each image that is converted.
	// 2 font matching information.
	// 4 filename wildcard matching information.
	// 8 Bates number information.
	//
	// Return value:
	// 0 - success
	// 1 - invalid logFilename


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_TreatImageNumericExtensionAs(char *imageExtension);
	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_TreatImageNumericExtAs(char *imageExtension);
	// Some images may have a numeric sequenced number extension (eg image.001, image.002 etc) which would normally prevent
	// the image from being identified as a valid one. To get around this problem use this
	// function and pass it the image extension type that a numeric extension will be interpreted
	// as (eg ".jpg", ".tif", ".png", ".gif", ".bmp", ".wmf", ".emf", ".pcx", ".tga")
	//
	// Return value:
	// 0 - success
	// 1 - extension not specified
	// 2 - extension does not start with a .
	// 3 - extension is not 4 characters long


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_TreatImageTmpExtensionAs(char *imageExtension);
	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_TreatImageTmpExtAs(char *imageExtension);
	// Some images may have a TMP extension which would normally prevent
	// the image from being identified as a valid one. To get around this problem use this
	// function and pass it the image extension type that a TMP extension will be interpreted
	// as (eg ".jpg", ".tif", ".png", ".gif", ".bmp", ".wmf", ".emf", ".pcx", ".tga")
	//
	// Return value:
	// 0 - success
	// 1 - extension not specified
	// 2 - extension does not start with a .
	// 3 - extension is not 4 characters long


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_TreatImageExtensionAs(char *sourceExtension, char *targetExtension);
	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_TreatImageExtAs(char *sourceExtension, char *targetExtension);
	// Some images may have a non-standard image extension which would normally prevent
	// the image from being identified as a valid one. To get around this problem use this
	// function to map one of these extensions as a known one
	// (eg ".jpg", ".tif", ".png", ".gif", ".bmp", ".wmf", ".emf", ".pcx", ".tga")
	//
	// Return value:
	// 0 - success
	// 1 - source extension not specified
	// 2 - source extension does not start with a .
	// 3 - target extension not specified
	// 4 - target extension does not start with a .
	// 5 - target extension is not 4 characters long
	// 6 - max image extension mappings already defined


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MetaImageMaxMP(double maxmp);
	// Specifies the meta image (EMF or WMF) maximum rendering size.
	//
	// Return value:
	// 0 - success
	// 1 - invalid maxmp parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MetaImageMaxMP_Int(int maxmp);
	// Specifies the meta image (EMF or WMF) maximum rendering size.
	//
	// Return value:
	// 0 - success
	// 1 - invalid maxmp parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MetaImageScale(double percentage);
	// Specifies the meta image (EMF or WMF) scaling factor.
	//
	// Return value:
	// 0 - success
	// 1 - invalid percentage parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MetaImageScale_Int(int percentage);
	// Specifies the meta image (EMF or WMF) scaling factor.
	//
	// Return value:
	// 0 - success
	// 1 - invalid percentage parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MetaVerticalRenderScale(double scale);
	// Specifies the meta image (EMF or WMF) vertical scaling factor during rendering.
	//
	// Return value:
	// 0 - success
	// 1 - invalid scale parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MetaVerticalRenderScale_Int(int scale);
	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MetaVertRenderScale_Int(int scale);
	// Specifies the meta image (EMF or WMF) vertical scaling factor during rendering.
	//
	// Return value:
	// 0 - success
	// 1 - invalid scale parameter

    
	[DllImport("Image2PDF.dll")]
	static  void I2PDF_MetaMargins(void);
	// Preserve the margins around the meta image (no matter how large they might be)
	//
	// Return value:
	// None


	[DllImport("Image2PDF.dll")]
	static void I2PDF_MetaToNativePDF();
	// Forces meta image files to be converted into a native PDF representation
	//
	// Return value: none 


    [DllImport("Image2PDF.dll")]
    static void I2PDF_CenterMetaImageOnPage();
    // Force a native rendered page to have the contents centered on the page based on the content of the meta image that is actually rendered into the PDF
    //
    // Return value: none 


	#define FORCED_FONT_QUALITY_DRAFT			1
    #define FORCED_FONT_QUALITY_PROOF			2
    #define FORCED_FONT_QUALITY_NONANTIALIASED	3
    #define FORCED_FONT_QUALITY_ANIALIASED		4
    #define FORCED_FONT_QUALITY_CLEARTYPE       5
    [DllImport("Image2PDF.dll")]
    static int I2PDF_MetaBitmapForcedFontQuality(int quality);
    [DllImport("Image2PDF.dll")]
    static int I2PDF_MetaBitmapForcedFontQ(int quality);
    // This API can only be used if the I2PDF_MetaToNativePDF API has NOT been used as it controls the font quality when rendering the meta image file into a bitmap. 
    //
    // Return value:
    // 0 - success
    // 1 - invalid quality


	[DllImport("Image2PDF.dll")]
	static void I2PDF_MetaTextFitBoundingRect();
	// If text in a meta image file is larger than the defined bounding rectangle this command will progressively 
	// reduce the font size until it can fit the text within the defined bounding area.
	//
	// Return value: none 


	[DllImport("Image2PDF.dll")]
	static void I2PDF_UseEMFDeviceSize();
	// Determine the size of an EMF meta file by using the embedded reference device bounds.
	//
	// Return value: none 


	[DllImport("Image2PDF.dll")]
	static void I2PDF_UseEMFFrameSize();
	// Determine the size of an EMF meta file by using the embedded frame size.
	//
	// Return value: none 


	[DllImport("Image2PDF.dll")]
	static int I2PDF_MetaDefaultFont(char *fontname);
	// If a font cannot be matched then this allows the specification of one of the standard PDF fonts to be used:
	//
	// Courier 
	// Courier-Bold 
	// Courier-BoldOblique 
	// Courier-Oblique 
	// Helvetica 
	// Helvetica-Bold 
	// Helvetica-BoldOblique 
	// Helvetica-Oblique 
	// Times-Roman 
	// Times-Bold 
	// Times-Italic 
	// Times-BoldItalic 
	//
	// Return value:
	// 0 - success
	// 1 - invalid font name


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MetaDefaultFontXScaling(double scaleFactor);
	// If a font cannot be matched (perhaps because it is not a True Type font with a CMAP record) then this 
	// allows the arbitrary scaling of the width of the font in order to better match the actual physical 
	// dimensions of the substituted font. Can only be used in conjunction with I2PDF_MetaDefaultFont
	//
	// Return value:
	// 0 - success
	// 1 - invalid scale factor parameter


	[DllImport("Image2PDF.dll")]
	static void I2PDF_UseArabicContextualForms(void);
	[DllImport("Image2PDF.dll")]
	static void I2PDF_UseArabicContextForms(void);
	// By default, when Arabic Unicode text is used (codepage CP1256) the Arabic glyphs do not 
	// take into account the context and relationship with other Arabic and non-Arabic text.
	// This command will enable the analysis of the surrounding text in order to change the glyph to one of
	// the contextual Arabic alternatives (known as initial, medial, final and isolated forms)
	//
	// Return value: none 


	[DllImport("Image2PDF.dll")]
	static void I2PDF_EmbedFonts(void);
	// If a document is converted which uses an unusual font that is not likely to be installed on a target 
	// system then this	command will ensure that all of the font details are embedded within the PDF so that 
	// the target system that a PDF may be viewed on does not require the font in order to display the text 
	// within the PDF correctly.
	//
	// Return value: none 


	#define VERTICAL_ALIGNMENT_TOP				1
	#define VERTICAL_ALIGNMENT_MIDDLE			2
	#define VERTICAL_ALIGNMENT_BOTTOM			3
	#define HORIZONTAL_ALIGNMENT_LEFT			1
	#define HORIZONTAL_ALIGNMENT_CENTER			2
	#define HORIZONTAL_ALIGNMENT_RIGHT			3
	[DllImport("Image2PDF.dll")]
	static int I2PDF_ImageStamp(char *image, int verticalPosition, int horizontalPosition, double margin);
	[DllImport("Image2PDF.dll")]
	static int I2PDF_ImageStamp_Int(char *image, int verticalPosition, int horizontalPosition, int margin);
	// Specifies the name and location of an image that is "stamped" at the specified 
	// location on each page of the output PDF document. A margin between the image
	// stamp and the edge of the page can be specified if required.
	//
	// Return value:
    // 0 - success
    // 1 - invalid image parameter
    // 2 - invalid vertical position
    // 3 - invalid horizontal position
    // 4 - invalid margin


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MetaStampImageMaxMP(double maxmp);
	// Specifies the meta image (EMF or WMF) maximum rendering size for an image stamp.
	//
	// Return value:
	// 0 - success
	// 1 - invalid maxmp parameter
	

	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MetaStampImageMaxMP_Int(int maxmp);
	// Specifies the meta image (EMF or WMF) maximum rendering size for an image stamp.
	//
	// Return value:
	// 0 - success
	// 1 - invalid maxmp parameter
	

	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MetaStampImageScale(double percentage);
	// Specifies the meta image (EMF or WMF) scaling factor for an image stamp
	//
	// Return value:
	// 0 - success
	// 1 - invalid percentage parameter
	

	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MetaStampImageScale_Int(int percentage);
	// Specifies the meta image (EMF or WMF) scaling factor for an image stamp
	//
	// Return value:
	// 0 - success
	// 1 - invalid percentage parameter
	

	[DllImport("Image2PDF.dll")]
	static int I2PDF_StampURL(char *url);
	// This is optional and specifies the URL that the image stamp will open in the default browser when it is clicked on.
	//
	// A maximum of 128 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("Image2PDF.dll")]
	static int I2PDF_MetaToNativeFontSubstitution(char *fontSubs);
	[DllImport("Image2PDF.dll")]
	static int I2PDF_MetaToNativeFontSubs(char *fontSubs);
	// If a font cannot be matched (perhaps because it is not a True Type font with a CMAP record) 
	// then this allows an alternative font and specific character substitutions to be made. 
	//
	// Return value:
	// 0 - success
	// 1 - invalid substitution description
	// 2 - maximum number of substitution strings already defined


	#define SLIDESHOW_WIPE_RIGHT						1
	#define SLIDESHOW_WIPE_UP							2
	#define SLIDESHOW_WIPE_LEFT							3
	#define SLIDESHOW_WIPE_DOWN							4
	#define SLIDESHOW_BARN_DOORS_HORIZONTAL_OUT			5
	#define SLIDESHOW_BARN_DOORS_HORIZONTAL_IN			6
	#define SLIDESHOW_BARN_DOORS_VERTICAL_OUT			7
	#define SLIDESHOW_BARN_DOORS_VERTICAL_IN			8
	#define SLIDESHOW_BOX_OUT							9
	#define SLIDESHOW_BOX_IN							10
	#define SLIDESHOW_BLINDS_HORIZONTAL					11
	#define SLIDESHOW_BLINDS_VERTICAL					12
	#define SLIDESHOW_DISSOLVE							13
	#define SLIDESHOW_GLITTER_RIGHT						14
	#define SLIDESHOW_GLITTER_DOWN						15
	#define SLIDESHOW_GLITTER_TOP_LEFT_TO_BOTTOM_RIGHT	16
	#define SLIDESHOW_REPLACE							17
	[DllImport("Image2PDF.dll")]
	static int I2PDF_SlideShow(int transition, double transitionDuration, double pageDisplayDuration);
	[DllImport("Image2PDF.dll")]
	static int I2PDF_SlideShow_Int(int transition, int transitionDuration, int pageDisplayDuration);
	// Forces the PDF document to be displayed full screen with the chosen screen transition between each page.
	//
	// Return value:
	// 0 - success
	// 1 - invalid transition
	// 2 - invalid transition duration
	// 3 - invalid page display duration


	[DllImport("Image2PDF.dll")]
	static void I2PDF_DeleteImagesOnConvert();
	// When the PDF document has been successfully produced all of the images converted to PDF are deleted.
	//
	// Return value: none 


	[DllImport("Image2PDF.dll")]
	static int I2PDF_SetBorder(double left, double top, double right, double bottom);
	[DllImport("Image2PDF.dll")]
	static int I2PDF_SetBorder_Int(int left, int top, int right, int bottom);
	// Allows a border to be inserted between the image and the edge of the PDF page.
	// The border color can be specified by using one of the three I2PDF_SetBorderColor_Real/Int/Web APIs below.
	// This can be useful if you want to add an image stamp to each page but do not want it to obscure the image.
	//
	// Return value:
	// 0 - success
	// 1 - invalid left value
	// 2 - invalid top value
	// 3 - invalid right value
	// 4 - invalid bottom value


	[DllImport("Image2PDF.dll")]
	static int I2PDF_SetBorderColor_Real(double red, double green, double blue);
	// Set the border color to use when I2PDF_SetBorder has been used.
	// Color is made up of a combination of three components: red, green and blue.
	// The value of each color component controls how much of that color is displayed, with a value of
	// 0.0 representing none up to a value of 100.0 representing the maximum value.
	//
	// Return value:
	// 0 - success
	// 1 - invalid red value
	// 2 - invalid green value
	// 3 - invalid blue value


	[DllImport("Image2PDF.dll")]
	static int I2PDF_SetBorderColor_Int(int red, int green, int blue);
	// Set the border color to use when I2PDF_SetBorder has been used.
	// Color is made up of a combination of three components: red, green and blue.
	// The value of each color component controls how much of that color is displayed, with a value of
	// 0 representing none up to a value of 255 representing the maximum value.
	//
	// Return value:
	// 0 - success
	// 1 - invalid red value
	// 2 - invalid green value
	// 3 - invalid blue value


	[DllImport("Image2PDF.dll")]
	static int I2PDF_SetBorderColor_Web(char *color);
	// Set the border color to use when I2PDF_SetBorder has been used.
	// Color is made up of a combination of three components: red, green and blue.
	// Web colours are specified by using three pairs of hexadecimal digits.
	// The value of each color component controls how much of that color is displayed, with a value of
	// 00 representing none up to a value of FF representing the maximum value.
	//
	// Return value:
	// 0 - success
	// 1 - invalid color value


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SilentRunning();
	// Prevents information from being printed to the console window
	//
	// Return value: none


    [DllImport("Image2PDF.dll")]
	static void I2PDF_PreventPDFOverwrite();
	// Prevents an existing PDF from being overwritten
	//
	// Return value: none


   	[DllImport("Image2PDF.dll")]
    static int I2PDF_SaveFailureBackupPDF(char *filename);
	// Will save the PDF to a backup filename if the required file cannot be written (perhaps because another application has the target PDF currently open). 
	//
	// Return value:
	// 0 - success
	// 1 - invalid filename


    [DllImport("Image2PDF.dll")]
	static void I2PDF_IncludeTIFFOCRText();
	// Includes any OCR'd text stored within the TIFF file (eg produced by Microsoft Document Imaging) as invisible "searchable" text within the PDF. 
	//
	// Return value: none


    [DllImport("Image2PDF.dll")]
	static void I2PDF_SaveTIFFOCRText(char *text);
	// Outputs any OCR'd text stored within the TIFF file (eg produced by Microsoft Document Imaging) into a text file with the same name and in the same location as the produced PDF.
	//
	// Return value: none


    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailureCopyTo(char *copyToDir);
    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailCopyTo(char *copyToDir);
    // Allows images that fail to be copied to the specified directory (for a manual or monitoring process to deal with).
    //
    // Return value:
    // 0 - success
    // 1 - invalid copyToDir


    [DllImport("Image2PDF.dll")]
    static void I2PDF_LoadImageFailureSkip();
    [DllImport("Image2PDF.dll")]
    static void I2PDF_LoadImageFailSkip();
    // Allows images that fail to be skipped over so that all valid images are still converted and a PDF produced. 
    //
    // Return value: none


    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailurePage_Real(int width, int height, double dblBackgroundRed, double dblBackgroundGreen, double dblBackgroundBlue, char *message);
    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailPg_Real(int width, int height, double dblBackgroundRed, double dblBackgroundGreen, double dblBackgroundBlue, char *message);
    // Allows images that fail to still have a page in the PDF but with the required message.
    //
    // Return value:
    // 0 - success
    // 1 - invalid width
    // 2 - invalid height
    // 3 - invalid backgroundRed
    // 4 - invalid backgroundGreen
    // 5 - invalid backgroundBlue
    // 6 - invalid message 

 
    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailurePage_Int(int width, int height, int backgroundRed, int backgroundGreen, int backgroundBlue, char *message);
    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailPg_Int(int width, int height, int backgroundRed, int backgroundGreen, int backgroundBlue, char *message);
    // Allows images that fail to still have a page in the PDF but with the required message.
    //
    // Return value:
    // 0 - success
    // 1 - invalid width
    // 2 - invalid height
    // 3 - invalid backgroundRed
    // 4 - invalid backgroundGreen
    // 5 - invalid backgroundBlue
    // 6 - invalid message 


    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailurePage_Web(int width, int height, char *backgroundColor, char *message);
    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailPg_Web(int width, int height, char *backgroundColor, char *message);
    // Allows images that fail to still have a page in the PDF but with the required message.
    //
    // Return value:
    // 0 - success
    // 1 - invalid width
    // 2 - invalid height
    // 3 - invalid backgroundColor
    // 4 - invalid message 


    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailurePageFont_Real(int iSize, char *font, double dblFillRed, double dblFillGreen, double dblFillBlue, int iStyle, double dblOtherRed, double dblOtherGreen, double dblOtherBlue);
    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailPgFnt_Real(int iSize, char *font, double dblFillRed, double dblFillGreen, double dblFillBlue, int iStyle, double dblOtherRed, double dblOtherGreen, double dblOtherBlue);
    // Controls the display of the failure message text specified in I2PDF_LoadImageFailurePage_Real/Int/Web.
    //
    // Return value:
    // 0 - success
    // 1 - invalid size
    // 2 - invalid font
    // 3 - invalid fillRed
    // 4 - invalid fillGreen
    // 5 - invalid fillBlue
    // 6 - invalid style
    // 7 - invalid otherRed
    // 8 - invalid otherGreen
    // 9 - invalid otherBlue 


    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailurePageFont_Int(int iSize, char *font, int fillRed, int fillGreen, int fillBlue, int iStyle, int otherRed, int otherGreen, int otherBlue);
    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailPgFnt_Int(int iSize, char *font, int fillRed, int fillGreen, int fillBlue, int iStyle, int otherRed, int otherGreen, int otherBlue);
    // Controls the display of the failure message text specified in I2PDF_LoadImageFailurePage_Real/Int/Web.
    //
    // Return value:
    // 0 - success
    // 1 - invalid size
    // 2 - invalid font
    // 3 - invalid fillRed
    // 4 - invalid fillGreen
    // 5 - invalid fillBlue
    // 6 - invalid style
    // 7 - invalid otherRed
    // 8 - invalid otherGreen
    // 9 - invalid otherBlue 


    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailurePageFont_Web(int iSize, char *font, char *fillColor, int iStyle, char *otherColor);
    [DllImport("Image2PDF.dll")]
    static int I2PDF_LoadImageFailPgFnt_Web(int iSize, char *font, char *fillColor, int iStyle, char *otherColor);
    // Controls the display of the failure message text specified in I2PDF_LoadImageFailurePage_Real/Int/Web.
    //
    // Return value:
    // 0 - success
    // 1 - invalid size
    // 2 - invalid font
    // 3 - invalid fillColor
    // 4 - invalid style
    // 5 - invalid otherColor 


	// *****************************************************************************
	// Bates (Page/Document) Numbering
	// *****************************************************************************
	

	[DllImport("Image2PDF.dll")]
	static int I2PDF_BatesFormat(char *format);
	// Specifies the text to display on each page of the output PDF. This is typically
	// a combination of static text plus one or more special Bates markup formatting labels.
	// See the manual for full details.
	//
	// Return value:
	// 0 - success
	// 1 - invalid format


	[DllImport("Image2PDF.dll")]
	static int I2PDF_BatesLocation(int verticalPosition, int horizontalPosition, int orientation, double margin);
	// This is optional and specifies the location that the Bates "number" is displayed on each page of the output PDF document. 
	//
	// Return value:
	// 0 - success
	// 1 - invalid verticalPosition
	// 2 - invalid horizontalPosition
	// 3 - invalid textOrientation
	// 4 - invalid margin 


	[DllImport("Image2PDF.dll")]
	static int I2PDF_BatesLocation_Int(int verticalPosition, int horizontalPosition, int orientation, int margin);
	// This is optional and specifies the location that the Bates "number" is displayed on each page of the output PDF document. 
	//
	// Return value:
	// 0 - success
	// 1 - invalid verticalPosition
	// 2 - invalid horizontalPosition
	// 3 - invalid textOrientation
	// 4 - invalid margin 


	#define TEXT_STYLE_NORMAL					1
	#define TEXT_STYLE_STROKE					2
	[DllImport("Image2PDF.dll")]
	static int I2PDF_BatesFont_Real(int iSize, char *FontID, double dblFillRed, double dblFillGreen, double dblFillBlue, int iStyle, double dblOtherRed, double dblOtherGreen, double dblOtherBlue);
	// This is optional and controls the display of the Bates "number". 
	//
	// Return value:
	// 0 - success
	// 1 - invalid size
	// 2 - invalid fontID
	// 3 - invalid fillRed
	// 4 - invalid fillGreen
	// 5 - invalid fillBlue
	// 6 - invalid style
	// 7 - invalid otherRed
	// 8 - invalid otherGreen
	// 9 - invalid otherBlue 


	[DllImport("Image2PDF.dll")]
	static int I2PDF_BatesFont_Int(int iSize, char *FontID, int fillRed, int fillGreen, int fillBlue, int iStyle, int otherRed, int otherGreen, int otherBlue);
	// This is optional and controls the display of the Bates "number". 
	//
	// Return value:
	// 0 - success
	// 1 - invalid size
	// 2 - invalid font
	// 3 - invalid fillRed
	// 4 - invalid fillGreen
	// 5 - invalid fillBlue
	// 6 - invalid style
	// 7 - invalid otherRed
	// 8 - invalid otherGreen
	// 9 - invalid otherBlue 


	[DllImport("Image2PDF.dll")]
	static int I2PDF_BatesFont_Web(int iSize, char *FontID, char *fillColor, int iStyle, char *otherColor);
	// This is optional and controls the display of the Bates "number". 
	//
	// Return value:
	// 0 - success
	// 1 - invalid size
	// 2 - invalid font
	// 3 - invalid fillColor
	// 4 - invalid style
	// 5 - invalid otherColor


	[DllImport("Image2PDF.dll")]
	static int I2PDF_BatesFile(char *filename);
	// This is optional but is useful if you want to have sequential numbering continue automatically between documents. 
	//
	// Return value:
	// 0 - success
	// 1 - invalid filename


	[DllImport("Image2PDF.dll")]
	static int I2PDF_BatesNumber(unsigned int initialValue);
	// This is optional and defines the initial Bates number used. 
	//
	// Return value:
	// 0 - success


	[DllImport("Image2PDF.dll")]
	static int I2PDF_BatesIncrement(unsigned int value);
	// This is optional and defines the amount by which the Bates number is incremented with use. 
	//
	// Return value:
	// 0 - success
	// 1 - invalid value


	#define BATES_BACKGROUND_FILLED_RECT		1
	#define BATES_BACKGROUND_OUTLINE_RECT		2
	[DllImport("Image2PDF.dll")]
	static int I2PDF_BatesBackground_Real(int shape, double backgroundRed, double backgroundGreen, double backgroundBlue, double borderRed, double borderGreen, double borderBlue);
	// This is optional and if not specified no background is displayed behind the Bates "number". 
	//
	// Return value:
	// 0 - success
	// 1 - invalid shape
	// 2 - invalid backgroundRed
	// 3 - invalid backgroundGreen
	// 4 - invalid backgroundBlue
	// 5 - invalid borderRed
	// 6 - invalid borderGreen
	// 7 - invalid borderBlue 


	[DllImport("Image2PDF.dll")]
	static int I2PDF_BatesBackground_Int(int shape, int backgroundRed, int backgroundGreen, int backgroundBlue, int borderRed, int borderGreen, int borderBlue);
	// This is optional and if not specified no background is displayed behind the Bates "number". 
	//
	// Return value:
	// 0 - success
	// 1 - invalid shape
	// 2 - invalid backgroundRed
	// 3 - invalid backgroundGreen
	// 4 - invalid backgroundBlue
	// 5 - invalid borderRed
	// 6 - invalid borderGreen
	// 7 - invalid borderBlue 


	[DllImport("Image2PDF.dll")]
	static int I2PDF_BatesBackground_Web(int shape, char *backgroundColor, char *borderColor);
	// This is optional and if not specified no background is displayed behind the Bates "number". 
	//
	// Return value:
	// 0 - success
	// 1 - invalid shape
	// 2 - invalid backgroundColor
	// 3 - invalid borderColor


	// *************************************************************************
	// Image Transformations
	// *************************************************************************
	
	
	[DllImport("Image2PDF.dll")]
	static int I2PDF_Rotate(int angle);
	// Rotate image clockwise by a fixed amount (90, 180 or 270 degrees)
	//
	// Return value:
	// 0 - success
	// 1 - invalid angle
	

	#define AUTOROTATE_PORTRAIT		1
	#define AUTOROTATE_LANDSCAPE	2
	[DllImport("Image2PDF.dll")]
	static int I2PDF_AutoRotate(int orientation, int angle);
	// Rotate image clockwise (if required) by a fixed amount (90 or 270 degrees) 
	// so that it is in portrait or landscape orientation
	//
	// Return value:
	// 0 - success
	// 1 - invalid orientation
	// 2 - invalid angle
	

	#define FLIP_HORIZONTAL		1
	#define FLIP_VERTICAL		2
	[DllImport("Image2PDF.dll")]
	static int I2PDF_Flip(int orientation);
	// Flip image horizontally (mirroring) or vertically
	//
	// Return value:
	// 0 - success
	// 1 - invalid orientation
	

	[DllImport("Image2PDF.dll")]
	static void I2PDF_Grayscale(void);
	// Ensure that an image is in grayscale - if it is in color it will be converted
	//
	// Return value:
	// None
	

	[DllImport("Image2PDF.dll")]
	static void I2PDF_Negative(void);
	// Invert (negative) image
	//
	// Return value:
	// None
	

	[DllImport("Image2PDF.dll")]
	static int I2PDF_JpegCompress(int quality);
	// Force re-compression of all JPEG images, quality can be between 1 (low)
	// to 35 (high). A value of 0 will turn re-compression off.
	//
	// Return value:
	// 0 - success
	// 1 - invalid angle


	// *************************************************************************
	// PDF Settings
	// *************************************************************************
	#define OUTLINE_FORMAT_FILENAME	1
	#define OUTLINE_FORMAT_NAME		2
	#define STYLE_NONE				0
	#define STYLE_LOWERCASE			1
	#define STYLE_UPPERCASE			2
	#define STYLE_CAPITALISE		3
	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_SetOutline(unsigned int format, unsigned int style);
	// This turns on the generation of a bookmark for each image that is in the 
	// output PDF document.
	//
	// format can be either "filename" (this is the name of the image file including 
	// the image extension but not including the full filepath) or "name" (same as 
	// filename but without the image extension).
	//
	// style can be: "lowercase", "uppercase", "capitalise" or "none".
	//
	// Return value:
	// 0 - success
	// 1 - invalid format parameter
	// 2 - invalid style parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_SetOutlineTitle(char *title);
	// If an outline is created this will set the title to be used instead of the default one.
	//
	// Return value:
	// 0 - success
	// 1 - title not specified
	// 2 - title too long

	#define PDF_PERMISSION_READ_ONLY    0
	#define PDF_PERMISSION_EDIT			1 
	#define PDF_PERMISSION_EDIT_EXTRA   2
	#define PDF_PERMISSION_COPY         4
	#define PDF_PERMISSION_PRINT        8
	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_SetPermissions(unsigned int iPermissions);
	// Allows the setting of any combination of permissions in one go
	//
    // Return value:
    // 0 - success
    // 1 - invalid permissions

	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPermissionEdit();
	// Allows editing/changing of the PDF document but NOT adding or changing of text 
	// notes and AcroForm fields.
	//
	// Return value: none 


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPermissionEditExtra();
	// Allows the adding and changing of text notes and AcroForm fields within a PDF document.
	//
	// Return value: none 


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPermissionCopy();
	// Allows the copying of text and graphics from the PDF document.
	//
	// Return value: none 


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPermissionPrint();
	// Allows printing of the PDF document.
	//
	// Return value: none 


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_SetOwnerPassword(char *password);
	// The owner of a PDF document would enter this password in order to view it
	// and make changes and perform actions that may be restricted to a normal user.
	//
	// A maximum of 32 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_SetUserPassword(char *password);
	// In order that only the intended user can view the PDF document, they must type
	// in this password, otherwise the user is not allowed to read the PDF document.
	//
	// A maximum of 32 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_EncryptionLevel(unsigned int level, unsigned int force);
	//Specifies the level of encryption that is to be used on the PDF document. 
	// If not specified the default level of 40 bits is used. 
	//
	// level must be either 40 (low) or 128 (high)
	// force must be 1 to force the encryption or 0
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_MinImageSize(unsigned int width, unsigned int height);
	// Specifies the minimum image width and height required for an image to be converted.
	//
	// width and height must be > 0
	//
	// Return value:
	// 0 - success
	// 1 - invalid width
	// 2 - invalid height


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_SetDPI(unsigned int dpi);
	// PDF documents use a default resolution setting of 72 DPI. Images created for 
	// screen display under Windows will probably have a resolution of 96 DPI. If you 
	// have created images for printing then you will probably need to use 300 or 600 DPI.
	//
	// If you do not adjust the default resolution setting then when displayed within a 
	// PDF document on screen a 96 DPI image will appear 25% larger than expected. This 
	// gets much worse for a 300 DPI image which will appear 416% larger than expected.
	//
    // dpi must be between 9 and 2880 inclusive, or 0 to force the use of the actual
    // image dpi that is recorded in the image file
    //
	// Return value:
	// 0 - success
	// 1 - invalid parameter - dpi specified is less than 9
	// 2 - invalid parameter - dpi specified is greater than 2880


	// *************************************************************************
	// PDF Meta Information
	// *************************************************************************
	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_SetProducer(char *producer);
	// The name of the application that converted the document from its native format to PDF.
	//
	// A maximum of 256 characters can be used.
	// 
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_SetCreator(char *creator);
	// If the document was converted into a PDF document from another form, this is 
	// usually the name of the application that created the original document.
	//
	// A maximum of 256 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_SetAuthor(char *author);
	// The name of the person who created the PDF document.
	//
	// A maximum of 256 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_SetTitle(char *title);
	// The PDF document's title.
	//
	// A maximum of 256 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_SetSubject(char *subject);
	// The PDF document's subject.
	//
	// A maximum of 256 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("Image2PDF.dll")]
	static unsigned int I2PDF_SetKeywords(char *keywords);
	// A list of keywords associated with the PDF document.
	//
	// A maximum of 256 characters can be used.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetCreationDate();
	// The date that the PDF document was created.
	//
	// This is set using the current local time of the PC.
	//
	// Return value: none


	// *************************************************************************
	// PDF Viewer Preferences
	// *************************************************************************
	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetViewerPreferenceCenterWindow();
	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetViewPrefCenterWindow();
	// The window displaying the PDF document should be displayed in the center of 
	// the computer's screen.
	//
	// Return value: none


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetViewerPreferenceHideToolbar();
	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetViewPrefHideToolbar();
	// The PDF viewer's toolbar should be hidden when the PDF document is active.
	//
	// Return value: none


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetViewerPreferenceHideMenubar();
	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetViewPrefHideMenubar();
	// The PDF viewer's menubar should be hidden when the PDF document is active.
	//
	// Return value: none


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetViewerPreferenceHideWindowUI();
	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetViewPrefHideWindowUI();
	// The user interface elements within the PDF document's window should be hidden.
	//
	// Return value: none


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetViewerPreferenceFitWindow();
	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetViewPrefFitWindow();
	// The PDF viewer should resize the window displaying the PDF document to fit the 
	// size of the first displayed page of the PDF document.
	//
	// Return value: none


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPageModeOutlines();
	// The PDF viewer should show the outline (ie bookmark) navigation item when the 
	// PDF document is open.
	//
	// Return value: none


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPageModeNone();
	// The PDF viewer should not show the outline (ie bookmark) or thumbnail navigation
	// items when the PDF document is open.
	//
	// This is the default if no other page mode is specified.
	//
	// Return value: none


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPageModeUseThumbs();
	// The PDF viewer should show the thumbnail navigation item when the PDF document 
	// is open.
	//
	// Return value: none


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPageModeFullScreen();
	// The PDF viewer should open the PDF document in full-screen mode without showing 
	// the menu bar, window controls or any other window.
	//
	// Return value: none


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPageLayoutSinglePage();
	// Display the pages one page at a time.
	//
	// Return value: none


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPageLayoutOneColumn();
	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPageLayout1Col();
	// Display the pages in one column.
	//
	// Return value: none


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPageLayoutTwoColumnLeft();
	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPageLayout2ColLeft();
	// Display the pages in two columns, with odd-numbered pages on the left.
	//
	// Return value: none


	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPageLayoutTwoColumnRight();
	[DllImport("Image2PDF.dll")]
	static void I2PDF_SetPageLayout2ColRight();
	// Display the pages in two columns, with odd-numbered pages on the right.
	//
	// Return value: none


	// *************************************************************************
	// Specifies the name and location of the produced PDF document, 
	// *************************************************************************
	[DllImport("Image2PDF.dll")]
	#define OPTION_NONE			0
	#define OPTION_OPEN_PDF		1
	#define OPTION_RESET		2
	static unsigned int I2PDF_MakePDF(char *output, int options, char *errorText, unsigned int maxErrorTextSize);
	// Generate the output PDF according to the settings already selected through
	// the Application Programming Interface functions above.
	//
    // To have the output PDF open in the default PDF viewer set the OPTION_OPEN_PDF
    // bit flag in the options parameter.
	//
    // To have all settings applied reset after PDF has been generated set the OPTION_RESET
    // bit flag in the options parameter.
	//
	// Return value:
	// 0 - success
	// 1 - invalid parameter
	// 2 - output pdf could not be opened
	// 3 - internal PDF generation error - error description returned in errorText
	// 4 - PDF file already exists and could not be overwritten - it is possibly being held open by a PDF viewer application


	[DllImport("Image2PDF.dll")]
	static void I2PDF_Reset();
	// Reset all settings including the list of images added.
	//
	// Return value: none
};
